@@ -181,7 +181,7 @@ static double hz = 0.;
 static time_t _getStartTime(void) {
         struct sysinfo info;
         if (sysinfo(&info) < 0) {
-                LogError("system statistic error -- cannot get system uptime: %s\n", STRERROR);
+                Log_error("system statistic error -- cannot get system uptime: %s\n", STRERROR);
                 return 0;
         }
         return Time_now() - info.uptime;
@@ -309,7 +309,9 @@ static bool _parseProcPidIO(Proc_T proc) {
                         }
                 } else {
                         // file_readProc() already printed a DEBUG() message
-                        return false;
+                        // return false;
+                        // sometimes no io data is available, this is not a problem.
+                        return true;
                 }
         }
         return true;
@@ -339,6 +341,7 @@ static bool _parseProcPidCmdline(Proc_T proc, ProcessEngine_Flags pflags) {
                         }
                 }
                 fclose(f);
+                StringBuffer_trim(proc->name);
                 // Fallback to procfs stat process name if cmdline was empty (even kernel-space processes have information here)
                 if (! StringBuffer_length(proc->name)) {
                         char buffer[8192];
@@ -405,16 +408,6 @@ static bool _parseProcFdCount(Proc_T proc) {
         proc->data.filedescriptors.open = file_count - 2;
 
         // get process's limits
-#ifdef HAVE_PRLIMIT
-        struct rlimit limits;
-        if (prlimit(proc->data.pid, RLIMIT_NOFILE, NULL, &limits) != 0) {
-                DEBUG("prlimit failed: %s\n", STRERROR);
-                return false;
-        }
-        proc->data.filedescriptors.limit.soft = limits.rlim_cur;
-        proc->data.filedescriptors.limit.hard = limits.rlim_max;
-#else
-        // Try to collect the command-line from the procfs cmdline (user-space processes)
         snprintf(path, sizeof(path), "/proc/%d/limits", proc->data.pid);
         FILE *f = fopen(path, "r");
         if (f) {
@@ -433,7 +426,6 @@ static bool _parseProcFdCount(Proc_T proc) {
                 DEBUG("system statistic error -- cannot open %s\n", path);
                 return false;
         }
-#endif
 
         return true;
 }
@@ -519,7 +511,7 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
         glob_t globbuf;
         int rv = glob("/proc/[0-9]*", 0, NULL, &globbuf);
         if (rv) {
-                LogError("system statistic error -- glob failed: %d (%s)\n", rv, STRERROR);
+                Log_error("system statistic error -- glob failed: %d (%s)\n", rv, STRERROR);
                 return 0;
         }
         ProcessTree_T *pt = CALLOC(sizeof(ProcessTree_T), globbuf.gl_pathc);
@@ -532,8 +524,9 @@ int initprocesstree_sysdep(ProcessTree_T **reference, ProcessEngine_Flags pflags
         time_t starttime = _getStartTime();
         for (size_t i = 0; i < globbuf.gl_pathc; i++) {
                 proc.data.pid = atoi(globbuf.gl_pathv[i] + 6); // skip "/proc/"
-                if (_parseProcPidStat(&proc) && _parseProcPidStatus(&proc) && _parseProcPidIO(&proc) && _parseProcPidCmdline(&proc, pflags) && _parseProcFdCount(&proc)) {
+                if (_parseProcPidStat(&proc) && _parseProcPidStatus(&proc) && _parseProcPidIO(&proc) && _parseProcPidCmdline(&proc, pflags)) {
                         // Non-mandatory statistics (may not exist)
+                        _parseProcFdCount(&proc);
                         _parseProcPidAttrCurrent(&proc);
                         // Set the data in ptree only if all process related reads succeeded (prevent partial data in the case that continue was called during data collecting)
                         pt[count].pid = proc.data.pid;
@@ -616,7 +609,7 @@ bool used_system_memory_sysdep(SystemInfo_T *si) {
         unsigned long long       zfsarcsize = 0ULL;
 
         if (! file_readProc(buf, sizeof(buf), "meminfo", -1, NULL)) {
-                LogError("system statistic error -- cannot get system memory info\n");
+                Log_error("system statistic error -- cannot get system memory info\n");
                 goto error;
         }
 
@@ -631,7 +624,7 @@ bool used_system_memory_sysdep(SystemInfo_T *si) {
         } else {
                 DEBUG("'MemAvailable' value not available on this system. Attempting to calculate available memory manually...\n");
                 if (! (ptr = strstr(buf, "MemFree:")) || sscanf(ptr + 8, "%lu", &mem_free) != 1) {
-                        LogError("system statistic error -- cannot get real memory free amount\n");
+                        Log_error("system statistic error -- cannot get real memory free amount\n");
                         goto error;
                 }
                 if (! (ptr = strstr(buf, "Buffers:")) || sscanf(ptr + 8, "%lu", &buffers) != 1)
@@ -655,11 +648,11 @@ bool used_system_memory_sysdep(SystemInfo_T *si) {
 
         /* Swap */
         if (! (ptr = strstr(buf, "SwapTotal:")) || sscanf(ptr + 10, "%lu", &swap_total) != 1) {
-                LogError("system statistic error -- cannot get swap total amount\n");
+                Log_error("system statistic error -- cannot get swap total amount\n");
                 goto error;
         }
         if (! (ptr = strstr(buf, "SwapFree:")) || sscanf(ptr + 9, "%lu", &swap_free) != 1) {
-                LogError("system statistic error -- cannot get swap free amount\n");
+                Log_error("system statistic error -- cannot get swap free amount\n");
                 goto error;
         }
         si->swap.size = (unsigned long long)swap_total * 1024;
@@ -694,7 +687,7 @@ bool used_system_cpu_sysdep(SystemInfo_T *si) {
         char buf[8192];
 
         if (! file_readProc(buf, sizeof(buf), "stat", -1, NULL)) {
-                LogError("system statistic error -- cannot read /proc/stat\n");
+                Log_error("system statistic error -- cannot read /proc/stat\n");
                 goto error;
         }
 
@@ -746,7 +739,7 @@ bool used_system_cpu_sysdep(SystemInfo_T *si) {
                         // linux >= 2.6.33
                         break;
                 default:
-                        LogError("system statistic error -- cannot read cpu usage\n");
+                        Log_error("system statistic error -- cannot read cpu usage\n");
                         goto error;
         }
 
@@ -838,7 +831,7 @@ bool available_statistics(SystemInfo_T *si) {
         char buf[8192];
 
         if (! file_readProc(buf, sizeof(buf), "stat", -1, NULL)) {
-                LogError("system statistic error -- cannot read /proc/stat\n");
+                Log_error("system statistic error -- cannot read /proc/stat\n");
                 return false;
         }
 
@@ -879,15 +872,15 @@ bool available_statistics(SystemInfo_T *si) {
                         si->statisticsAvailable |= Statistics_CpuUser | Statistics_CpuNice | Statistics_CpuSystem | Statistics_CpuIOWait | Statistics_CpuHardIRQ | Statistics_CpuSoftIRQ | Statistics_CpuSteal | Statistics_CpuGuest | Statistics_CpuGuestNice;
                         break;
                 default:
-                        LogError("system statistic error -- cannot read cpu usage\n");
+                        Log_error("system statistic error -- cannot read cpu usage\n");
                         return false;
         }
 
         si->statisticsAvailable |= Statistics_FiledescriptorsPerSystem | Statistics_FiledescriptorsPerProcess;
 
-#ifdef HAVE_PRLIMIT
-        si->statisticsAvailable |= Statistics_FiledescriptorsPerProcessMax;
-#endif
+        struct stat sb;
+        if (stat("/proc/sys/fs/file-nr", &sb) == 0)
+                si->statisticsAvailable |= Statistics_FiledescriptorsPerProcessMax;
 
         return true;
 }
